(_api_reference)=
# API Reference

[Configuration Options](api/config)
: All of the detailed options possible in {py:class}`sasktran2.Config`

[The Radiative Transfer Engine](api/engine)
: The core {py:class}`sasktran2.Engine` object

[Model Geometries](api/model_geometry.rst)
: Everything related to setting up the global model geometry

[Constituents](api/constituents.rst)
: All of the available atmospheric constituents in `sasktran2.constituents.*`

[Optical Properties](api/optical.md)
: The optical properties in `sasktran2.optical.*`

[Output](api/output.rst)
: Information on the available output formats

[Viewing Geometry](api/viewing_geometry.rst)
: Classes related to the viewing geometry construction

[Climatology](api/climatology.rst)
: The built in climatologies in `sasktran2.climatology.*`

[Geodesy](api/geodetic.md)
: Tools to deal with geodetic reference systems such as WGS84

[Mie](api/mie.md)
: Tools to calculate Mie parameters

[Databases](api/database.md)
: Tools to manage downloading external databases and generating internal databases

[Utility](api/util.rst)
: Utility functionality in `sasktran2.util.*`

```{toctree}
:maxdepth: 2
:hidden:

api/config
api/engine
api/model_geometry
api/atmosphere
api/constituents
api/optical
api/output
api/viewing_geometry
api/climatology
api/geodetic
api/database
api/util
api/mie
```
